(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     25840,        644]
NotebookOptionsPosition[     24679,        602]
NotebookOutlinePosition[     25164,        621]
CellTagsIndexPosition[     25121,        618]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["PhasePlot", "Title",
 CellChangeTimes->{{3.416504214464581*^9, 3.416504217157411*^9}}],

Cell[TextData[{
 "Bruce Shapiro\n6 April 2008\n\nThis notebook is distributed under the terms \
of the LGPL license, as described at\n",
 ButtonBox["http://www.gnu.org/copyleft/lesser.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.gnu.org/copyleft/lesser.html"], None}],
 "\n\nBased loosely on Eric Weisstein's notebook:\n",
 ButtonBox["http://mathworld.wolfram.com/notebooks/DifferentialEquations/\
PhasePortrait.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/notebooks/DifferentialEquations/\
PhasePortrait.nb"], None}],
 "\nWeisstein's notebook only plots specific functions and is not general. "
}], "Text",
 CellChangeTimes->{{3.416503920251026*^9, 3.41650398233578*^9}, {
  3.41650407909214*^9, 3.416504104408983*^9}, {3.4165041397218943`*^9, 
  3.416504151390592*^9}, {3.416504317257016*^9, 3.416504333292313*^9}, {
  3.416509265014392*^9, 3.416509271420388*^9}, {3.4165094709011717`*^9, 
  3.4165094891868057`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BeginPackage", "[", "\"\<PhasePlot`\>\"", "]"}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.416509050772047*^9, 3.416509058339005*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PhasePlot", "::", "usage"}], "=", 
   "\"\<PhasePlot[odes, ic, {t, tstart, tend}, options}] returns a graphics \
object that is the phase portrait of the two-dimensional or three-dimensional \
system of odes.\\nic is a list of ininitial condition points.\\nt is the time \
variable in in odes.\\ntstart, tend are the start and end times of the \
plot.\\noptions may be any options for \
Plot.\\n\\nExample:\\n\\nPhasePlot[{u'[t]\[Equal] (1/4) u[t] - v[t], v'[t] \
\[Equal] u[t]},{{0, 1},  {0, .7}}, {t, 0,  50}, PlotRange \[Rule] {{-10, 10}, \
{-10, 10}}]\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41650928615427*^9, 3.416509366987125*^9}, {
  3.41650950076167*^9, 3.416509506265964*^9}, {3.416511302860682*^9, 
  3.416511324522751*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.416509082884104*^9, 3.416509089316965*^9}}],

Cell["Define some utility functions", "Subsection",
 CellChangeTimes->{{3.416510465265709*^9, 3.41651046834618*^9}}],

Cell["Equivalent to FilterOptions in M5", "Text",
 CellChangeTimes->{{3.416510502700171*^9, 3.416510512324861*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Filter", "[", 
     RowBox[{"f_", ",", " ", 
      RowBox[{"options___", "?", "OptionQ"}]}], "]"}], ":=", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Sequence", "@@", 
     RowBox[{"FilterRules", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "options", "}"}], "]"}], ",", 
       RowBox[{"Options", "[", "f", "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Define the function PhasePlot", "Subsection",
 CellChangeTimes->{{3.416504157008925*^9, 3.416504160634054*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PhasePlot", "[", 
   RowBox[{
    RowBox[{"odes_", "?", "ListQ"}], ",", "   ", 
    RowBox[{"ic_", "?", "ListQ"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t_", ",", " ", "tstart_", ",", " ", "tend_"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"opt___", "?", "OptionQ"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "solver", ",", " ", "SysIC", ",", " ", "variables", ",", " ", "varnames",
       ",", " ", "variable", ",", " ", "debug", ",", " ", "dpr", ",", " ", 
      "icheck"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "to", " ", "turn", " ", "on", " ", "debugging", " ", "set", " ", 
       "\"\<debug\>\""}], "\[Rule]", " ", "True"}], " ", "*)"}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"debug", " ", "=", " ", 
      RowBox[{
       RowBox[{"\"\<debug\>\"", "/.", 
        RowBox[{"{", "opt", "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{"\"\<debug\>\"", "\[Rule]", " ", "False"}], "}"}]}]}], ";", 
     " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dpr", "[", "u___", "]"}], ":=", " ", 
      RowBox[{"If", "[", 
       RowBox[{"debug", ",", " ", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<dbg: PhasePlot: \>\"", ",", " ", "u"}], "]"}]}], 
       "]"}]}], ";", " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "check", " ", "to", " ", "make", " ", "sure", " ", "the", " ", "system",
        " ", "has", " ", "dimension", " ", "2"}], " ", "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "odes", "]"}], "\[Equal]", "3"}], ",", " ", 
       RowBox[{"Return", "[", 
        RowBox[{"PhasePlot3D", "[", 
         RowBox[{"odes", ",", " ", "ic", ",", " ", 
          RowBox[{"{", 
           RowBox[{"t", ",", " ", "tstart", ",", " ", "tend"}], "}"}], ",", 
          " ", "opt"}], "]"}], "]"}]}], "]"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "odes", "]"}], "\[NotEqual]", " ", "2"}], ",", 
       " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Error: PhasePlot: Expecting a system of two or three ODES. This \
system appears to have \>\"", ",", " ", 
          RowBox[{"Length", "[", "odes", "]"}], ",", " ", "\"\< ODES.\>\""}], 
         "]"}], ";", " ", 
        RowBox[{"Return", "[", "$Failed", "]"}], ";"}]}], " ", 
      "\[IndentingNewLine]", "]"}], ";", " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"iccheck", " ", "=", " ", 
      RowBox[{"And", "@@", 
       RowBox[{"(", 
        RowBox[{"ListQ", "/@", "ic"}], ")"}]}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{"Not", "[", "iccheck", "]"}], ",", " ", 
       RowBox[{
        RowBox[{
        "Print", "[", 
         "\"\<Error: PhasePlot: Initial Conditions should be a list of \
points.\>\"", "]"}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"iccheck", " ", "=", " ", 
      RowBox[{"Union", "[", 
       RowBox[{"Length", "/@", "ic"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{"Not", "[", 
        RowBox[{
         RowBox[{"Length", "[", "iccheck", "]"}], "\[Equal]", "1"}], "]"}], 
       ",", " ", 
       RowBox[{
        RowBox[{
        "Print", "[", 
         "\"\<Error: PhasePlot: Initial Conditions should be a list of points \
of the form {{x1,y1}, {x2, y2}, ...} - at least one of the points does not \
have dimension 2.\>\"", "]"}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"iccheck", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", " ", "2"}], ",", " ", 
       
       RowBox[{
        RowBox[{
        "Print", "[", 
         "\"\<Error: PhasePlot: Initial Conditions should be a list of points \
in 2D.\>\"", "]"}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", " ", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "Determine", " ", "the", " ", "names", " ", "of", " ", "the", " ", 
        "variables"}], ",", " ", 
       RowBox[{
       "the", " ", "functions", " ", "to", " ", "be", " ", "plotted"}]}], " ",
       "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"variable", "[", 
       RowBox[{
        RowBox[{"u_", "'"}], "[", "v_", "]"}], "]"}], ":=", " ", 
      RowBox[{"u", "[", "v", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"variable", "[", "u___", "]"}], ":=", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Error: unable to determine variable: \>\"", ",", " ", "u"}], 
         "]"}], ";", " ", 
        RowBox[{"Return", "[", "$Failed", "]"}]}], ")"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"variables", " ", "=", " ", 
      RowBox[{"variable", "/@", 
       RowBox[{"(", 
        RowBox[{"First", "/@", 
         RowBox[{"Flatten", "[", "odes", "]"}]}], ")"}]}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"varnames", " ", "=", " ", 
      RowBox[{"Head", "/@", "variables"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"dpr", "[", 
      RowBox[{"\"\<odes: \>\"", ",", " ", "odes"}], "]"}], ";", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"dpr", "[", 
      RowBox[{"\"\<vars: \>\"", ",", " ", "variables"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dpr", "[", 
      RowBox[{"\"\<varnames: \>\"", ",", " ", "varnames"}], "]"}], ";", " ", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "solver", " ", "is", " ", "a", " ", "wrapper", " ", "for", " ", 
       "NDSolve", " ", "to", " ", "solve", " ", "the", " ", "odes", " ", "on",
        " ", "a", " ", "single", " ", "curve", " ", "from", " ", "a", " ", 
       "given", " ", "initial", " ", "condition"}], " ", "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"solver", "[", 
       RowBox[{"u_", ",", " ", "v_"}], "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xvar", ",", " ", "yvar", ",", " ", "system"}], "}"}], ",", 
        " ", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"xvar", ",", " ", "yvar"}], "}"}], " ", "=", " ", 
          "varnames"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"system", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"odes", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"xvar", "[", "0", "]"}], "\[Equal]", "u"}], ",", " ", 
              RowBox[{
               RowBox[{"yvar", "[", "0", "]"}], "\[Equal]", "v"}]}], "}"}]}], 
           "]"}]}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"dpr", "[", 
          RowBox[{"\"\<system: \>\"", ",", " ", "system"}], "]"}], ";", " ", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"variables", "/.", "\[InvisibleSpace]", 
          RowBox[{
           RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
            RowBox[{"system", ",", "\[IndentingNewLine]", "variables", ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "tstart", ",", "tend"}], "}"}]}], "]"}], "[", 
           
           RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"solver", "[", 
       RowBox[{"{", 
        RowBox[{"u_", ",", " ", "v_"}], "}"}], "]"}], ":=", " ", 
      RowBox[{"solver", "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "calculate", " ", "all", " ", "the", " ", "suolutions", " ", "and", " ",
        "plot", " ", "them"}], " ", "*)"}], " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"popts", "=", 
         RowBox[{"Filter", "[", 
          RowBox[{"Plot", ",", " ", "opt"}], "]"}]}], "}"}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Evaluate", "[", 
          RowBox[{"solver", "/@", "ic"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", " ", "tstart", ",", " ", "tend"}], "}"}], ",", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"DisplayFunction", "\[Rule]", " ", "Identity"}], ",", " ", 
         "\[IndentingNewLine]", "popts"}], "]"}]}], "\[IndentingNewLine]", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.416502054736515*^9, 3.416502116064989*^9}, {
   3.416502154807107*^9, 3.416502196783038*^9}, {3.416502395316389*^9, 
   3.4165024025639553`*^9}, {3.4165024592106047`*^9, 3.41650275959639*^9}, {
   3.4165028504617147`*^9, 3.416502983732472*^9}, {3.416503030171555*^9, 
   3.416503112270104*^9}, {3.416503158089848*^9, 3.416503457741366*^9}, {
   3.416503514151313*^9, 3.416503559686523*^9}, {3.416503596789151*^9, 
   3.416503621685014*^9}, {3.416503663757708*^9, 3.4165036876964607`*^9}, {
   3.416503742652196*^9, 3.416503831967299*^9}, {3.416504349804563*^9, 
   3.416504475715889*^9}, 3.41650913766499*^9, {3.416509652553808*^9, 
   3.416509764681861*^9}, {3.416509932267667*^9, 3.4165101514909267`*^9}, {
   3.416510208344133*^9, 3.416510224863859*^9}, {3.416510274571356*^9, 
   3.416510307629799*^9}, {3.416510474216996*^9, 3.416510495352565*^9}, {
   3.41651056022197*^9, 3.416510576257434*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define the function PhasePlot", "Subsection",
 CellChangeTimes->{{3.416504157008925*^9, 3.416504160634054*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PhasePlot3D", "[", 
   RowBox[{
    RowBox[{"odes_", "?", "ListQ"}], ",", "   ", 
    RowBox[{"ic_", "?", "ListQ"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t_", ",", " ", "tstart_", ",", " ", "tend_"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"opt___", "?", "OptionQ"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "solver", ",", " ", "SysIC", ",", " ", "variables", ",", " ", "varnames",
       ",", " ", "variable", ",", " ", "debug", ",", " ", "dpr", ",", "  ", 
      "iccheck"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "to", " ", "turn", " ", "on", " ", "debugging", " ", "set", " ", 
       "\"\<debug\>\""}], "\[Rule]", " ", "True"}], " ", "*)"}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"debug", " ", "=", " ", 
      RowBox[{
       RowBox[{"\"\<debug\>\"", "/.", 
        RowBox[{"{", "opt", "}"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{"\"\<debug\>\"", "\[Rule]", " ", "False"}], "}"}]}]}], ";", 
     " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dpr", "[", "u___", "]"}], ":=", " ", 
      RowBox[{"If", "[", 
       RowBox[{"debug", ",", " ", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<dbg: PhasePlot3D: \>\"", ",", " ", "u"}], "]"}]}], 
       "]"}]}], ";", " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "check", " ", "to", " ", "make", " ", "sure", " ", "the", " ", "system",
        " ", "has", " ", "dimension", " ", "3"}], " ", "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "odes", "]"}], "\[NotEqual]", " ", "3"}], ",", 
       " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Error: PhasePlot: Expecting a system of two or three ODES. This \
system appears to have \>\"", ",", " ", 
          RowBox[{"Length", "[", "odes", "]"}], ",", " ", "\"\< ODES.\>\""}], 
         "]"}], ";", " ", 
        RowBox[{"Return", "[", "$Failed", "]"}], ";"}]}], " ", 
      "\[IndentingNewLine]", "]"}], ";", " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"iccheck", " ", "=", " ", 
      RowBox[{"And", "@@", 
       RowBox[{"(", 
        RowBox[{"ListQ", "/@", "ic"}], ")"}]}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{"Not", "[", "iccheck", "]"}], ",", " ", 
       RowBox[{
        RowBox[{
        "Print", "[", 
         "\"\<Error: PhasePlot: Initial Conditions should be a list of \
points.\>\"", "]"}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"iccheck", " ", "=", " ", 
      RowBox[{"Union", "[", 
       RowBox[{"Length", "/@", "ic"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{"Not", "[", 
        RowBox[{
         RowBox[{"Length", "[", "iccheck", "]"}], "\[Equal]", "1"}], "]"}], 
       ",", " ", 
       RowBox[{
        RowBox[{
        "Print", "[", 
         "\"\<Error: PhasePlot: Initial Conditions should be a list of points \
of the form {{x1,y1, z1}, {x2, y2, z2}, ...} - at least one of the points \
does not have dimension 3.\>\"", "]"}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"iccheck", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", " ", "3"}], ",", " ", 
       
       RowBox[{
        RowBox[{
        "Print", "[", 
         "\"\<Error: PhasePlot: Initial Conditions should be a list of points \
in 3D.\>\"", "]"}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", " ", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "Determine", " ", "the", " ", "names", " ", "of", " ", "the", " ", 
        "variables"}], ",", " ", 
       RowBox[{
       "the", " ", "functions", " ", "to", " ", "be", " ", "plotted"}]}], " ",
       "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"variable", "[", 
       RowBox[{
        RowBox[{"u_", "'"}], "[", "v_", "]"}], "]"}], ":=", " ", 
      RowBox[{"u", "[", "v", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"variable", "[", "u___", "]"}], ":=", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Error: unable to determine variable: \>\"", ",", " ", "u"}], 
         "]"}], ";", " ", 
        RowBox[{"Return", "[", "$Failed", "]"}]}], ")"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"variables", " ", "=", " ", 
      RowBox[{"variable", "/@", 
       RowBox[{"(", 
        RowBox[{"First", "/@", 
         RowBox[{"Flatten", "[", "odes", "]"}]}], ")"}]}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"varnames", " ", "=", " ", 
      RowBox[{"Head", "/@", "variables"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"dpr", "[", 
      RowBox[{"\"\<odes: \>\"", ",", " ", "odes"}], "]"}], ";", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"dpr", "[", 
      RowBox[{"\"\<vars: \>\"", ",", " ", "variables"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dpr", "[", 
      RowBox[{"\"\<varnames: \>\"", ",", " ", "varnames"}], "]"}], ";", " ", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "solver", " ", "is", " ", "a", " ", "wrapper", " ", "for", " ", 
       "NDSolve", " ", "to", " ", "solve", " ", "the", " ", "odes", " ", "on",
        " ", "a", " ", "single", " ", "curve", " ", "from", " ", "a", " ", 
       "given", " ", "initial", " ", "condition"}], " ", "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"solver", "[", 
       RowBox[{"u_", ",", " ", "v_", ",", " ", "w_"}], "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xvar", ",", " ", "yvar", ",", " ", "system"}], "}"}], ",", 
        " ", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"xvar", ",", " ", "yvar", ",", " ", "zvar"}], "}"}], " ", 
          "=", " ", "varnames"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"system", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"odes", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"xvar", "[", "0", "]"}], "\[Equal]", "u"}], ",", " ", 
              RowBox[{
               RowBox[{"yvar", "[", "0", "]"}], "\[Equal]", "v"}], ",", " ", 
              RowBox[{
               RowBox[{"zvar", "[", "0", "]"}], "\[Equal]", "w"}]}], "}"}]}], 
           "]"}]}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"dpr", "[", 
          RowBox[{"\"\<system: \>\"", ",", " ", "system"}], "]"}], ";", " ", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"variables", "/.", "\[InvisibleSpace]", 
          RowBox[{
           RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
            RowBox[{"system", ",", "\[IndentingNewLine]", "variables", ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "tstart", ",", "tend"}], "}"}]}], "]"}], "[", 
           
           RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"solver", "[", 
       RowBox[{"{", 
        RowBox[{"u_", ",", " ", "v_", ",", " ", "w_"}], "}"}], "]"}], ":=", 
      " ", 
      RowBox[{"solver", "[", 
       RowBox[{"u", ",", " ", "v", ",", " ", "w"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "calculate", " ", "all", " ", "the", " ", "suolutions", " ", "and", " ",
        "plot", " ", "them"}], " ", "*)"}], " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"popts", "=", 
         RowBox[{"Filter", "[", 
          RowBox[{"Plot", ",", " ", "opt"}], "]"}]}], "}"}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"ParametricPlot3D", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Evaluate", "[", 
          RowBox[{"solver", "/@", "ic"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", " ", "tstart", ",", " ", "tend"}], "}"}], ",", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"DisplayFunction", "\[Rule]", " ", "Identity"}], ",", " ", 
         "\[IndentingNewLine]", "popts"}], "]"}]}], "\[IndentingNewLine]", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.416502054736515*^9, 3.416502116064989*^9}, {
   3.416502154807107*^9, 3.416502196783038*^9}, {3.416502395316389*^9, 
   3.4165024025639553`*^9}, {3.4165024592106047`*^9, 3.41650275959639*^9}, {
   3.4165028504617147`*^9, 3.416502983732472*^9}, {3.416503030171555*^9, 
   3.416503112270104*^9}, {3.416503158089848*^9, 3.416503457741366*^9}, {
   3.416503514151313*^9, 3.416503559686523*^9}, {3.416503596789151*^9, 
   3.416503621685014*^9}, {3.416503663757708*^9, 3.4165036876964607`*^9}, {
   3.416503742652196*^9, 3.416503831967299*^9}, {3.416504349804563*^9, 
   3.416504475715889*^9}, 3.41650913766499*^9, {3.416509520975318*^9, 
   3.416509570543779*^9}, {3.4165098069442453`*^9, 3.416509807344369*^9}, {
   3.416509917705364*^9, 3.416509924336378*^9}, {3.4165099703915367`*^9, 
   3.416509978302712*^9}, {3.416510362538032*^9, 3.416510417985271*^9}, {
   3.416510518343404*^9, 3.416510525143901*^9}, {3.4165105997260036`*^9, 
   3.41651060785041*^9}, {3.416510638106463*^9, 3.416510638577681*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EndPackage", "[", "]"}], ";"}], " "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.416509106011372*^9, 3.4165091106700497`*^9}}]
},
AutoGeneratedPackage->Automatic,
CellGrouping->Manual,
WindowSize->{727, 723},
WindowMargins->{{Automatic, 222}, {Automatic, 202}},
ShowSelection->True,
FrontEndVersion->"6.0 for Linux x86 (64-bit) (June 19, 2007)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "PastelColor.nb", 
  CharacterEncoding -> "iso8859-1"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 92, 1, 75, "Title"],
Cell[685, 26, 983, 20, 200, "Text"],
Cell[1671, 48, 215, 6, 42, "Input",
 InitializationCell->True],
Cell[1889, 56, 816, 15, 241, "Input",
 InitializationCell->True],
Cell[2708, 73, 204, 5, 42, "Input",
 InitializationCell->True],
Cell[2915, 80, 116, 1, 39, "Subsection"],
Cell[3034, 83, 115, 1, 29, "Text"],
Cell[3152, 86, 491, 15, 87, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3668, 105, 117, 1, 39, "Subsection"],
Cell[3788, 108, 10296, 240, 1737, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14133, 354, 117, 1, 39, "Subsection"],
Cell[14253, 357, 10145, 233, 1693, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[24413, 593, 262, 7, 65, "Input",
 InitializationCell->True]
}
]
*)

(* End of internal cache information *)
